@@ -23,6 +23,10 @@
 #ifndef _ICINT_H_
 #define _ICINT_H_
 
+#ifdef HAVE_CONFIG_H
+#  include "../config.h"
+#endif
+
 #include "pixman.h"
 
 #include <stdlib.h>
@@ -33,9 +37,17 @@
 
 #include "slim_internal.h"
 
+/* C89 has implementation-defined behavior for % with negative operands.
+   C99 has well-defined behavior which is that / with integers rounds toward zero
+       and a%b is defined so that (a/b)*b + a%b == a.
 
+   The C99 version gives negative remainders rather than the modulus
+   in [0 .. b-1] that we want. This macro avoids using % with negative
+   operands to avoid both problems.
 
-
+   a and b are integers. b > 0.
+*/
+#define MOD(a, b) ((b) == 1 ? 0 : (a) >= 0 ? (a) % (b) : (b) - (-(a) - 1) % (b) - 1)
 
 typedef struct _IcPoint {
 	int16_t    x,y ;
@@ -61,7 +73,16 @@ typedef unsigned int	Mask;
 #define LOG2_BYTES_PER_SCANLINE_PAD	2
 #endif
 
+#define LSBFirst 0
+#define MSBFirst 1
 
+#ifdef WORDS_BIGENDIAN
+#  define IMAGE_BYTE_ORDER MSBFirst
+#  define BITMAP_BIT_ORDER MSBFirst
+#else
+#  define IMAGE_BYTE_ORDER LSBFirst
+#  define BITMAP_BIT_ORDER LSBFirst
+#endif
 
 
 #define MAXSHORT SHRT_MAX
@@ -536,7 +557,7 @@ extern void IcSetBits (IcStip *bits, int stride, IcStip data);
 /*
  * icblt.c
  */
-extern void __internal_linkage
+pixman_private void
 IcBlt (pixman_bits_t   *src, 
        IcStride	srcStride,
        int	srcX,
@@ -555,7 +576,7 @@ IcBlt (pixman_bits_t   *src,
        int	reverse,
        int	upsidedown);
 
-extern void __internal_linkage
+pixman_private void
 IcBlt24 (pixman_bits_t	    *srcLine,
 	 IcStride   srcStride,
 	 int	    srcX,
@@ -573,7 +594,7 @@ IcBlt24 (pixman_bits_t	    *srcLine,
 	 int	    reverse,
 	 int	    upsidedown);
     
-extern void __internal_linkage
+pixman_private void
 IcBltStip (IcStip   *src,
 	   IcStride srcStride,	    /* in IcStip units, not pixman_bits_t units */
 	   int	    srcX,
@@ -592,7 +613,7 @@ IcBltStip (IcStip   *src,
 /*
  * icbltone.c
  */
-extern void __internal_linkage
+pixman_private void
 IcBltOne (IcStip   *src,
 	  IcStride srcStride,
 	  int	   srcX,
@@ -610,7 +631,7 @@ IcBltOne (IcStip   *src,
 	  pixman_bits_t   bgxor);
  
 #ifdef IC_24BIT
-extern void __internal_linkage
+pixman_private void
 IcBltOne24 (IcStip    *src,
 	  IcStride  srcStride,	    /* IcStip units per scanline */
 	  int	    srcX,	    /* bit position of source */
@@ -632,13 +653,13 @@ IcBltOne24 (IcStip    *src,
  * icstipple.c
  */
 
-extern void __internal_linkage
+pixman_private void
 IcTransparentSpan (pixman_bits_t   *dst,
 		   pixman_bits_t   stip,
 		   pixman_bits_t   fgxor,
 		   int	    n);
 
-extern void __internal_linkage
+pixman_private void
 IcEvenStipple (pixman_bits_t   *dst,
 	       IcStride dstStride,
 	       int	dstX,
@@ -659,7 +680,7 @@ IcEvenStipple (pixman_bits_t   *dst,
 	       int	xRot,
 	       int	yRot);
 
-extern void __internal_linkage
+pixman_private void
 IcOddStipple (pixman_bits_t	*dst,
 	      IcStride	dstStride,
 	      int	dstX,
@@ -681,7 +702,7 @@ IcOddStipple (pixman_bits_t	*dst,
 	      int	xRot,
 	      int	yRot);
 
-extern void __internal_linkage
+pixman_private void
 IcStipple (pixman_bits_t   *dst,
 	   IcStride dstStride,
 	   int	    dstX,
@@ -730,9 +751,17 @@ typedef struct _IcPixels {
 typedef uint32_t Pixel;
 
 /* icutil.c */
-extern pixman_bits_t __internal_linkage
+pixman_private pixman_bits_t
 IcReplicatePixel (Pixel p, int bpp);
 
+/* fbtrap.c */
+
+pixman_private void
+fbRasterizeTrapezoid (pixman_image_t		*pMask,
+		      const pixman_trapezoid_t  *pTrap,
+		      int		x_off,
+		      int		y_off);
+
 /* XXX: This is to avoid including gc.h from the server includes */
 /* clientClipType field in GC */
 #define CT_NONE			0
@@ -765,40 +794,32 @@ _IcOnes(unsigned long mask);
 
 /* icformat.c */
 
-extern void __internal_linkage
+pixman_private void
 pixman_format_init (pixman_format_t *format, int format_code);
 
 /* icimage.c */
 
-extern pixman_image_t * __internal_linkage
+pixman_private pixman_image_t *
 pixman_image_createForPixels (IcPixels	*pixels,
 			pixman_format_t	*format);
 
 /* icpixels.c */
 
-extern IcPixels * __internal_linkage
+pixman_private IcPixels *
 IcPixelsCreate (int width, int height, int depth);
 
-extern IcPixels * __internal_linkage
+pixman_private IcPixels *
 IcPixelsCreateForData (pixman_bits_t *data, int width, int height, int depth, int bpp, int stride);
 
-extern void __internal_linkage
+pixman_private void
 IcPixelsDestroy (IcPixels *pixels);
 
 /* ictransform.c */
 
-extern int __internal_linkage
+pixman_private int
 pixman_transform_point (pixman_transform_t	*transform,
 		  pixman_vector_t	*vector);
 
-/* ictrap.c */
-
-extern void __internal_linkage
-IcRasterizeTrapezoid (pixman_image_t		*pMask,
-		      const pixman_trapezoid_t  *pTrap,
-		      int		x_off,
-		      int		y_off);
-
 /* Avoid unnessecary PLT entries.  */
 
 slim_hidden_proto(pixman_image_create)
@@ -806,6 +827,7 @@ slim_hidden_proto(pixman_color_to_pixel)
 slim_hidden_proto(pixman_format_init)
 slim_hidden_proto(pixman_image_destroy)
 slim_hidden_proto(pixman_fill_rectangles)
+slim_hidden_proto(pixman_image_set_component_alpha)
 slim_hidden_proto(pixman_image_set_repeat)
 slim_hidden_proto(pixman_composite)
 
@@ -818,7 +840,6 @@ slim_hidden_proto(pixman_composite)
 
 typedef struct _DirectFormat	*DirectFormatPtr;
 typedef struct _PictFormat	*PictFormatPtr;
-typedef struct _Picture		*PicturePtr;
 
 /*
  * While the protocol is generous in format support, the
@@ -946,7 +967,7 @@ typedef struct _Picture		*PicturePtr;
 #define PictureCmapPolicyColor	    3
 #define PictureCmapPolicyAll	    4
 
-extern int  PictureCmapPolicy __internal_linkage;
+extern int PictureCmapPolicy pixman_private;
 
 int	PictureParseCmapPolicy (const char *name);
 
@@ -971,6 +992,7 @@ typedef long long int	xFixed_32_32;
 # endif
 #endif
 
+typedef xFixed_32_32		xFixed_48_16;
 typedef uint32_t		xFixed_1_31;
 typedef uint32_t		xFixed_1_16;
 typedef int32_t		xFixed_16_16;
